OC.L10N.register(
    "tasks",
    {
    "Tasks" : "Zereginak",
    "Important" : "Garrantzitsua",
    "Today" : "Gaur",
    "Week" : "Astea",
    "All" : "Denak",
    "Current" : "Unekoa",
    "Completed" : "Betea",
    "Delete" : "Ezabatu",
    "Cancel" : "Ezeztatu",
    "Default" : "Lehenetsia",
    "Due date" : "Epemuga",
    "Start date" : "Hasiera data",
    "Priority" : "Lehentasuna",
    "Manually" : "Eskuz",
    "Alphabetically" : "Alfabetikoki",
    "_%n Completed Task_::_%n Completed Tasks_" : ["Zeregin bete %n","%n Zeregin Beteak"],
    "Tomorrow" : "Bihar",
    "Set start date" : "Ezarri hasteko eguna",
    "Set due date" : "Ezarri epemuga",
    "All day" : "Egun osoa",
    "When shared show full event" : "Partekatzean erakutsi gertaera osoa",
    "When shared hide this event" : "Partekatzean ezkutatu gertaera hau",
    "Edit" : "Editatu",
    "Download" : "Deskargatu",
    "Save" : "Gorde",
    "New List" : "Zerrenda berria",
    "An empty name is not allowed." : "Hutsa ez da izentzat onartzen.",
    "Settings" : "Ezarpenak",
    "Visibility of Smart Collections" : "Bilduma argien ikusgarritasuna",
    "Hidden" : "Ezkutua",
    "Visible" : "Agerian",
    "Automatic" : "Automatikoa"
},
"nplurals=2; plural=(n != 1);");
